Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1916)

Unified Diff: chrome/browser/policy/url_blacklist_manager_unittest.cc

Issue 1171333003: Move net::FormatUrl and friends outside of //net and into //components (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase again now that CQ is fixed Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/policy/url_blacklist_manager_unittest.cc
diff --git a/chrome/browser/policy/url_blacklist_manager_unittest.cc b/chrome/browser/policy/url_blacklist_manager_unittest.cc
index a21df066ef5e5c75f17321259d03b9206fb1c4b3..b00a9a3f35ef5b7f308083b695f2ab8ff48f1454 100644
--- a/chrome/browser/policy/url_blacklist_manager_unittest.cc
+++ b/chrome/browser/policy/url_blacklist_manager_unittest.cc
@@ -15,7 +15,7 @@
#include "base/thread_task_runner_handle.h"
#include "chrome/browser/policy/policy_helpers.h"
#include "components/policy/core/common/policy_pref_names.h"
-#include "components/url_fixer/url_fixer.h"
+#include "components/url_formatter/url_fixer.h"
#include "google_apis/gaia/gaia_urls.h"
#include "net/base/load_flags.h"
#include "net/base/net_errors.h"
@@ -25,7 +25,7 @@
// TODO(joaodasilva): this file should be moved next to
// components/policy/core/browser/url_blacklist_manager.(cc|h).
// However, url_fixer_upper.h can't be included from the component. Rather
// than having it mocked out, the actual url_fixer::SegmentURL call is used
// to make sure that the parsing of URL filters is correct.
namespace policy {
@@ -34,7 +34,7 @@ namespace {
// Helper to get the disambiguated SegmentURL() function.
URLBlacklist::SegmentURLCallback GetSegmentURLCallback() {
- return url_fixer::SegmentURL;
+ return url_formatter::SegmentURL;
}
class TestingURLBlacklistManager : public URLBlacklistManager {
« no previous file with comments | « chrome/browser/policy/managed_bookmarks_policy_handler.cc ('k') | chrome/browser/prefs/session_startup_pref.cc » ('j') | no next file with comments »
@@ -25,7 +25,7 @@
// components/policy/core/browser/url_blacklist_manager.(cc|h).
// However, url_fixer_upper.h can't be included from the component. Rather
-// than having it mocked out, the actual url_fixer::SegmentURL call is used
+// than having it mocked out, the actual url_formatter::SegmentURL call is used
// to make sure that the parsing of URL filters is correct.
namespace policy {

Powered by Google App Engine
This is Rietveld 408576698